@@ -287,6 +287,24 @@ class CatmaidNeuron(navis.TreeNeuron):
 
         return res
 
+    def __mul__(self, other, *args, **kwargs):
+        """Implement multiplication for coordinates (nodes, connectors)."""
+        # Exclude missing radii from multiplication
+        is_missing = self.nodes.radius == -1
+        n = super().__mul__(other, *args, **kwargs)
+        n.nodes.loc[is_missing, 'radius'] = -1
+
+        return n
+
+    def __truediv__(self, other, *args, **kwargs):
+        """Implement division for coordinates (nodes, connectors)."""
+        # Exclude missing radii from division
+        is_missing = self.nodes.radius == -1
+        n = super().__truediv__(other, *args, **kwargs)
+        n.nodes.loc[is_missing, 'radius'] = -1
+
+        return n
+
     def __hash__(self):
         # DO NOT REMOVE THIS! When defining __eq__ in subclass, _hash__ will
         # not be inherited and we have to explicitly define it
@@ -1124,7 +1142,6 @@ class CatmaidNeuronList(navis.NeuronList):
         return super().remove_duplicates(key=key, inplace=inplace)
 
 
-
 # This is for legacy but will be removed soon-ish
 Dotprops = navis.Dotprops
 Volume = navis.Volume
